@@ -67,7 +67,7 @@ object ReligionAutomation {
         // Buy religious buildings in cities if possible
         val citiesWithMissingReligiousBuildings = civInfo.cities.filter { city ->
             city.religion.getMajorityReligion() != null
-            && !city.cityConstructions.builtBuildings.containsAll(city.religion.getMajorityReligion()!!.buildingsPurchasableByBeliefs)
+            && !city.cityConstructions.isAllBuilt(city.religion.getMajorityReligion()!!.buildingsPurchasableByBeliefs)
         }
         if (citiesWithMissingReligiousBuildings.any()) {
             tryBuyAnyReligiousBuilding(civInfo)
