@@ -5,8 +5,8 @@ import com.unciv.logic.automation.Automation
 import com.unciv.logic.battle.Battle
 import com.unciv.logic.battle.GreatGeneralImplementation
 import com.unciv.logic.battle.MapUnitCombatant
+import com.unciv.logic.battle.TargetHelper
 import com.unciv.logic.city.City
-import com.unciv.logic.civilization.Civilization
 import com.unciv.logic.civilization.diplomacy.DiplomaticModifiers
 import com.unciv.logic.map.mapunit.MapUnit
 import com.unciv.logic.map.tile.Tile
@@ -20,32 +20,6 @@ import com.unciv.ui.screens.worldscreen.unit.actions.UnitActionsReligion
 
 object SpecificUnitAutomation {
 
-    private fun hasWorkableSeaResource(tile: Tile, civInfo: Civilization): Boolean =
-            tile.isWater && tile.improvement == null && tile.hasViewableResource(civInfo)
-
-    fun automateWorkBoats(unit: MapUnit) {
-        val closestReachableResource = unit.civ.cities.asSequence()
-                .flatMap { city -> city.getWorkableTiles() }
-                .filter {
-                    hasWorkableSeaResource(it, unit.civ)
-                            && (unit.currentTile == it || unit.movement.canMoveTo(it))
-                }
-                .sortedBy { it.aerialDistanceTo(unit.currentTile) }
-                .firstOrNull { unit.movement.canReach(it) }
-
-        when (closestReachableResource) {
-            null -> UnitAutomation.tryExplore(unit)
-            else -> {
-                unit.movement.headTowards(closestReachableResource)
-
-                // could be either fishing boats or oil well
-                val isImprovable = closestReachableResource.tileResource.getImprovements().any()
-                if (isImprovable && unit.currentTile == closestReachableResource)
-                    UnitActions.getWaterImprovementAction(unit)?.action?.invoke()
-            }
-        }
-    }
-
     fun automateGreatGeneral(unit: MapUnit): Boolean {
         //try to follow nearby units. Do not garrison in city if possible
         val maxAffectedTroopsTile = GreatGeneralImplementation.getBestAffectedTroopsTile(unit)
@@ -507,7 +481,7 @@ object SpecificUnitAutomation {
             .filter { destinationCity ->
                 destinationCity != airUnit.currentTile
                         && destinationCity.getTilesInDistance(airUnit.getRange())
-                    .any { BattleHelper.containsAttackableEnemy(it, MapUnitCombatant(airUnit)) }
+                    .any { TargetHelper.containsAttackableEnemy(it, MapUnitCombatant(airUnit)) }
             }
         if (citiesThatCanAttackFrom.isEmpty()) return
 
@@ -527,8 +501,7 @@ object SpecificUnitAutomation {
                     && tile.getOwner()!!.isAtWarWith(unit.civ)
                     && tile.getCity()!!.health > tile.getCity()!!.getMaxHealth() / 2
                     && Battle.mayUseNuke(MapUnitCombatant(unit), tile)) {
-                val blastRadius = unit.getMatchingUniques(UniqueType.BlastRadius)
-                    .firstOrNull()?.params?.get(0)?.toInt() ?: 2
+                val blastRadius = unit.getNukeBlastRadius()
                 val tilesInBlastRadius = tile.getTilesInDistance(blastRadius)
                 val civsInBlastRadius = tilesInBlastRadius.mapNotNull { it.getOwner() } +
                         tilesInBlastRadius.mapNotNull { it.getFirstUnit()?.civ }
@@ -575,7 +548,7 @@ object SpecificUnitAutomation {
             if (city.getTilesInDistance(unit.getRange())
                             .any {
                                 it.isVisible(unit.civ) &&
-                                BattleHelper.containsAttackableEnemy(
+                                TargetHelper.containsAttackableEnemy(
                                     it,
                                     MapUnitCombatant(unit)
                                 )
