@@ -8,6 +8,7 @@ import com.unciv.logic.civilization.CivFlags
 import com.unciv.logic.civilization.Civilization
 import com.unciv.logic.civilization.DiplomacyAction
 import com.unciv.logic.civilization.LocationAction
+import com.unciv.logic.civilization.MapUnitAction
 import com.unciv.logic.civilization.NotificationCategory
 import com.unciv.logic.civilization.NotificationIcon
 import com.unciv.logic.civilization.PlayerType
@@ -22,19 +23,15 @@ import com.unciv.models.ruleset.unique.UniqueType
 import com.unciv.models.ruleset.unit.BaseUnit
 import com.unciv.models.stats.Stat
 import com.unciv.ui.screens.victoryscreen.RankingType
-import java.util.*
 import kotlin.math.min
 import kotlin.math.pow
+import kotlin.random.Random
 
 /** Class containing city-state-specific functions */
 class CityStateFunctions(val civInfo: Civilization) {
 
     /** Attempts to initialize the city state, returning true if successful. */
     fun initCityState(ruleset: Ruleset, startingEra: String, unusedMajorCivs: Collection<String>): Boolean {
-        val startingTechs = ruleset.technologies.values.filter { it.hasUnique(UniqueType.StartingTech) }
-        for (tech in startingTechs)
-            civInfo.tech.techsResearched.add(tech.name) // can't be .addTechnology because the civInfo isn't assigned yet
-
         val allMercantileResources = ruleset.tileResources.values.filter { it.hasUnique(UniqueType.CityStateOnlyResource) }.map { it.name }
         val uniqueTypes = HashSet<UniqueType>()    // We look through these to determine what kinds of city states we have
 
@@ -67,7 +64,7 @@ class CityStateFunctions(val civInfo: Civilization) {
         return true
     }
 
-    fun turnsForGreatPersonFromCityState(): Int = ((37 + Random().nextInt(7)) * civInfo.gameInfo.speed.modifier).toInt()
+    fun turnsForGreatPersonFromCityState(): Int = ((37 + Random.Default.nextInt(7)) * civInfo.gameInfo.speed.modifier).toInt()
 
     /** Gain a random great person from the city state */
     fun giveGreatPersonToPatron(receivingCiv: Civilization) {
@@ -119,12 +116,12 @@ class CityStateFunctions(val civInfo: Civilization) {
             placedUnit.promotions.XP += unique.params[0].toInt()
         }
 
-        // Point to the places mentioned in the message _in that order_ (debatable)
-        val placedLocation = placedUnit.getTile().position
-        val locations = LocationAction(placedLocation, cities.city2.location, city.location)
+        // Point to the gifted unit, then to the other places mentioned in the message
+        val unitAction = sequenceOf(MapUnitAction(placedUnit.getTile().position))
+        val notificationActions = unitAction + LocationAction(cities.city2.location, city.location)
         receivingCiv.addNotification(
             "[${civInfo.civName}] gave us a [${militaryUnit.name}] as gift near [${city.name}]!",
-            locations,
+            notificationActions,
             NotificationCategory.Units,
             civInfo.civName,
             militaryUnit.name
@@ -232,18 +229,11 @@ class CityStateFunctions(val civInfo: Civilization) {
             val oldAllyName = civInfo.getAllyCiv()
             civInfo.setAllyCiv(newAllyName)
 
-            // If the city-state is captured by a civ, it stops being the ally of the civ it was previously an ally of.
-            //  This means that it will NOT HAVE a capital at that time, so if we run getCapital we'll get a crash!
-            val capitalLocation = if (civInfo.cities.isNotEmpty() && civInfo.getCapital() != null) civInfo.getCapital()!!.location else null
-
             if (newAllyName != null) {
                 val newAllyCiv = civInfo.gameInfo.getCivilization(newAllyName)
                 val text = "We have allied with [${civInfo.civName}]."
-                if (capitalLocation != null) newAllyCiv.addNotification(text, capitalLocation,
-                    NotificationCategory.Diplomacy, civInfo.civName,
-                    NotificationIcon.Diplomacy
-                )
-                else newAllyCiv.addNotification(text,
+                newAllyCiv.addNotification(text,
+                    getNotificationActions(),
                     NotificationCategory.Diplomacy, civInfo.civName,
                     NotificationIcon.Diplomacy
                 )
@@ -266,11 +256,8 @@ class CityStateFunctions(val civInfo: Civilization) {
             if (oldAllyName != null && civInfo.isAlive()) {
                 val oldAllyCiv = civInfo.gameInfo.getCivilization(oldAllyName)
                 val text = "We have lost alliance with [${civInfo.civName}]."
-                if (capitalLocation != null) oldAllyCiv.addNotification(text, capitalLocation,
-                    NotificationCategory.Diplomacy, civInfo.civName,
-                    NotificationIcon.Diplomacy
-                )
-                else oldAllyCiv.addNotification(text,
+                oldAllyCiv.addNotification(text,
+                    getNotificationActions(),
                     NotificationCategory.Diplomacy, civInfo.civName,
                     NotificationIcon.Diplomacy
                 )
@@ -280,6 +267,21 @@ class CityStateFunctions(val civInfo: Civilization) {
         }
     }
 
+    /** @return a Sequence of NotificationActions for use in addNotification, showing Capital on map if any, then opening diplomacy */
+    fun getNotificationActions() = sequence {
+        // Notification click will first point to CS location, if any, then open diplomacy.
+        // That's fine for the influence notifications and for afraid too.
+        //
+        // If the city-state is captured by a civ, it stops being the ally of the civ it was previously an ally of.
+        //  This means that it will NOT HAVE a capital at that time, so if we run getCapital()!! we'll get a crash!
+        // Or, City States can get stuck with only their Settler and no cities until late into a game if city placements are rare
+        // We also had `cities.asSequence() // in practice 0 or 1 entries, that's OK` before (a CS *can* have >1 cities but it will always raze conquests).
+        val capital = civInfo.getCapital()
+        if (capital != null)
+            yield(LocationAction(capital.location))
+        yield(DiplomacyAction(civInfo.civName))
+    }
+
     fun getDiplomaticMarriageCost(): Int {
         // https://github.com/Gedemon/Civ5-DLL/blob/master/CvGameCoreDLL_Expansion1/CvMinorCivAI.cpp, line 7812
         var cost = (500 * civInfo.gameInfo.speed.goldCostModifier).toInt()
@@ -552,7 +554,7 @@ class CityStateFunctions(val civInfo: Civilization) {
             civInfo.getDiplomacyManager(attacker).becomeWary()
         }
         else if (attacker.isMinorCivAggressor()) { // They've attacked a few
-            if (Random().nextBoolean()) { // 50% chance
+            if (Random.Default.nextBoolean()) { // 50% chance
                 civInfo.getDiplomacyManager(attacker).becomeWary()
             }
         }
@@ -591,7 +593,7 @@ class CityStateFunctions(val civInfo: Civilization) {
                 if (cityState.isAtWarWith(attacker))
                     probability += 50
 
-                if (Random().nextInt(100) <= probability) {
+                if (Random.Default.nextInt(100) <= probability) {
                     cityState.getDiplomacyManager(attacker).becomeWary()
                 }
             }
@@ -684,7 +686,7 @@ class CityStateFunctions(val civInfo: Civilization) {
     ):Sequence<Unique> {
         if (civInfo.isCityState()) return emptySequence()
 
-        return civInfo.getKnownCivs().asSequence().filter { it.isCityState() }
+        return civInfo.getKnownCivs().filter { it.isCityState() }
             .flatMap {
                 // We don't use DiplomacyManager.getRelationshipLevel for performance reasons - it tries to calculate getTributeWillingness which is heavy
                 val relationshipLevel =
@@ -701,8 +703,8 @@ class CityStateFunctions(val civInfo: Civilization) {
         val cityStateUniqueMap = when (relationshipLevel) {
             RelationshipLevel.Ally -> cityStateType.allyBonusUniqueMap
             RelationshipLevel.Friend -> cityStateType.friendBonusUniqueMap
-            else -> null
-        } ?: return emptySequence()
+            else -> return emptySequence()
+        }
         return if (uniqueType == null) cityStateUniqueMap.getAllUniques()
         else cityStateUniqueMap.getUniques(uniqueType)
     }
