@@ -513,7 +513,7 @@ class TileMap(initialCapacity: Int = 10) : IsPartOfGameInfoSerialization {
             var potentialCandidates = getPassableNeighbours(currentTile)
             while (unitToPlaceTile == null && tryCount++ < 10) {
                 unitToPlaceTile = potentialCandidates
-                        .sortedByDescending { if (unit.baseUnit.isLandUnit()) it.isLand else true } // Land units should prefer to go into land tiles
+                        .sortedByDescending { if (unit.baseUnit.isLandUnit() && !unit.cache.canMoveOnWater) it.isLand else true } // Land units should prefer to go into land tiles
                         .firstOrNull { unit.movement.canMoveTo(it) }
                 if (unitToPlaceTile != null) continue
                 // if it's not found yet, let's check their neighbours
@@ -615,7 +615,7 @@ class TileMap(initialCapacity: Int = 10) : IsPartOfGameInfoSerialization {
             .map { it to StartingLocation(it.position, it.improvement!!.removePrefix(startingLocationPrefix)) }
             .sortedBy { it.second.nation }  // vanity, or to make diffs between un-gzipped map files easier
             .forEach { (tile, startingLocation) ->
-                tile.changeImprovement(null)
+                tile.removeImprovement()
                 startingLocations.add(startingLocation)
             }
         setStartingLocationsTransients()
