@@ -1,6 +1,7 @@
 package com.unciv.models.ruleset.tech
 
 import com.badlogic.gdx.graphics.Color
+import com.unciv.logic.UncivShowableException
 import com.unciv.models.ruleset.IRulesetObject
 import com.unciv.models.ruleset.Ruleset
 import com.unciv.models.ruleset.RulesetObject
@@ -82,10 +83,22 @@ class Era : RulesetObject() {
             }.map { it.first }.distinct()
     }
 
-    fun getStartingUnits(): List<String> {
+    fun getStartingUnits(ruleset: Ruleset): MutableList<String> {
         val startingUnits = mutableListOf<String>()
-        repeat(startingSettlerCount) { startingUnits.add(startingSettlerUnit) }
-        repeat(startingWorkerCount) { startingUnits.add(startingWorkerUnit) }
+        val startingSettlerName: String =
+            if (startingSettlerUnit in ruleset.units) startingSettlerUnit
+            else ruleset.units.values
+                .firstOrNull { it.hasUnique(UniqueType.FoundCity) }
+                ?.name
+                ?: throw UncivShowableException("No Settler unit found for era $name")
+        val startingWorkerName: String =
+            if (startingWorkerCount == 0 || startingWorkerUnit in ruleset.units) startingWorkerUnit
+            else ruleset.units.values
+                .firstOrNull { it.hasUnique(UniqueType.BuildImprovements) }
+                ?.name
+                ?: throw UncivShowableException("No Worker unit found for era $name")
+        repeat(startingSettlerCount) { startingUnits.add(startingSettlerName) }
+        repeat(startingWorkerCount) { startingUnits.add(startingWorkerName) }
         repeat(startingMilitaryUnitCount) { startingUnits.add(startingMilitaryUnit) }
         return startingUnits
     }
