@@ -10,7 +10,7 @@ import com.unciv.models.stats.Stats
 import com.unciv.ui.components.Fonts
 import com.unciv.utils.Log
 import com.unciv.utils.debug
-import java.util.*
+import java.util.Locale
 
 /**
  *  This collection holds all translations for the game.
@@ -233,12 +233,15 @@ class Translations : LinkedHashMap<String, TranslationEntry>(){
 
 // Expect a literal [ followed by a captured () group and a literal ].
 // The group may contain any number of any character except ] - pattern [^]]
+@Suppress("RegExpRedundantEscape") // Some Android versions need ]}) escaped
 val squareBraceRegex = Regex("""\[([^]]*)\]""")
 
 // Analogous as above: Expect a {} pair with any chars but } in between and capture that
+@Suppress("RegExpRedundantEscape") // Some Android versions need ]}) escaped
 val curlyBraceRegex = Regex("""\{([^}]*)\}""")
 
 // Analogous as above: Expect a <> pair with any chars but > in between and capture that
+@Suppress("RegExpRedundantEscape") // Some Android versions need ]}) escaped
 val pointyBraceRegex = Regex("""\<([^>]*)\>""")
 
 
@@ -296,7 +299,9 @@ object TranslationActiveModsCache {
  */
 fun String.tr(hideIcons:Boolean = false): String {
     val language:String = UncivGame.Current.settings.language
-    if (contains('<') && contains('>')) { // Conditionals!
+
+    // '<' and '>' checks for quick 'no' answer, regex to ensure that no one accidentally put '><' and ruined things
+    if (contains('<') && contains('>') && pointyBraceRegex.containsMatchIn(this)) { // Conditionals!
         /**
          * So conditionals can contain placeholders, such as <vs [unitFilter] units>, which themselves
          * can contain multiple filters, such as <vs [{Military} {Water}] units>.
