@@ -9,7 +9,7 @@ import com.unciv.models.TutorialTrigger
 import com.unciv.models.ruleset.Tutorial
 import com.unciv.models.ruleset.unique.UniqueType
 import com.unciv.models.stats.INamed
-import com.unciv.ui.components.KeyCharAndCode
+import com.unciv.ui.components.input.KeyCharAndCode
 import com.unciv.ui.images.ImageGetter
 import com.unciv.ui.popups.Popup
 import com.unciv.ui.screens.civilopediascreen.FormattedLine
