@@ -10,9 +10,9 @@ import com.unciv.UncivGame
 import com.unciv.logic.files.MapSaver
 import com.unciv.logic.map.MapParameters
 import com.unciv.models.ruleset.RulesetCache
-import com.unciv.ui.components.extensions.onChange
 import com.unciv.ui.components.extensions.pad
 import com.unciv.ui.components.extensions.toLabel
+import com.unciv.ui.components.input.onChange
 import com.unciv.ui.screens.basescreen.BaseScreen
 import com.unciv.ui.screens.victoryscreen.LoadMapPreview
 import com.unciv.utils.Concurrency
@@ -32,7 +32,7 @@ class MapFileSelectTable(
     // The SelectBox auto displays the text a object.toString(), which on the FileHandle itself includes the folder path.
     //  So we wrap it in another object with a custom toString()
     private class MapWrapper(val fileHandle: FileHandle, val mapParameters: MapParameters) {
-        override fun toString(): String = mapParameters.baseRuleset + " | "+ fileHandle.name()
+        override fun toString(): String = mapParameters.baseRuleset + " | " + fileHandle.name()
     }
     private val mapWrappers= ArrayList<MapWrapper>()
 
@@ -44,10 +44,11 @@ class MapFileSelectTable(
         add(mapFileLabel).left()
         add(mapFileSelectBox)
             // because SOME people gotta give the hugest names to their maps
-            .width(columnWidth * 2 / 3)
+            .width(columnWidth - 40f - mapFileLabel.prefWidth)
             .right().row()
         add(miniMapWrapper)
             .pad(15f)
+            .maxWidth(columnWidth - 20f)
             .colspan(2).center().row()
 
         mapFileSelectBox.onChange { onSelectBoxChange() }
@@ -86,7 +87,6 @@ class MapFileSelectTable(
             .sortedWith(compareBy(UncivGame.Current.settings.getCollatorFromLocale()) { it.toString() })
             .sortedByDescending { it.mapParameters.baseRuleset == newGameScreen.gameSetupInfo.gameParameters.baseRuleset }
             .forEach { mapFiles.add(it) }
-        mapFileSelectBox.items = mapFiles
 
         // Pre-select: a) map saved within last 15min or b) map named in mapParameters or c) alphabetically first
         // This is a kludge - the better way would be to have a "play this map now" menu button in the editor
@@ -97,9 +97,21 @@ class MapFileSelectTable(
                     ?: mapFiles.firstOrNull { it.fileHandle.name() == mapParameters.name }
                     ?: mapFiles.firstOrNull()
                     ?: return
+
+        // since mapFileSelectBox.selection.setProgrammaticChangeEvents() defaults to true, this would
+        // kill the mapParameters.name we would like to look for when determining what to pre-select -
+        // so do it ***after*** getting selectedItem - but control programmaticChangeEvents anyway
+        // to avoid the overhead of doing a full updateRuleset + updateTables + startMapPreview
+        // (all expensive) for something that will be overthrown momentarily
+        mapFileSelectBox.selection.setProgrammaticChangeEvents(false)
+        mapFileSelectBox.items = mapFiles
+
+        // Now, we want this ON because the event removes map selections which are pulling mods
+        // that trip updateRuleset - so that code should still be active for the pre-selection
+        mapFileSelectBox.selection.setProgrammaticChangeEvents(true)
         mapFileSelectBox.selected = selectedItem
-        mapParameters.name = selectedItem.toString()
-        newGameScreen.gameSetupInfo.mapFile = selectedItem.fileHandle
+        // In the event described above, we now have: mapFileSelectBox.selected != selectedItem
+        // Do NOT try to put back the "bad" preselection!
     }
 
     private fun onSelectBoxChange() {
@@ -111,10 +123,20 @@ class MapFileSelectTable(
         newGameScreen.gameSetupInfo.gameParameters.mods = LinkedHashSet(mapMods.second)
         newGameScreen.gameSetupInfo.gameParameters.baseRuleset = mapMods.first.firstOrNull()
             ?: mapFileSelectBox.selected.mapParameters.baseRuleset
-        newGameScreen.updateRuleset()
+        val success = newGameScreen.tryUpdateRuleset()
         newGameScreen.updateTables()
         hideMiniMap()
-        startMapPreview(mapFile)
+        if (success) {
+            startMapPreview(mapFile)
+        } else {
+            // Mod error - the options have been reset by updateRuleset
+            // Note SelectBox doesn't react sensibly to _any_ clear - Group, Selection or items
+            val items = mapFileSelectBox.items
+            items.removeIndex(mapFileSelectBox.selectedIndex)
+            // Changing the array itself is not enough, SelectBox gets out of sync, need to call setItems()
+            mapFileSelectBox.items = items
+            // Note - this will have triggered a nested onSelectBoxChange()!
+        }
     }
 
     private fun startMapPreview(mapFile: FileHandle) {
@@ -124,7 +146,7 @@ class MapFileSelectTable(
                 if (!isActive) return@run
                 map.setTransients(newGameScreen.ruleset, false)
                 if (!isActive) return@run
-                // ReplyMap still paints outside its bounds - so we subtract padding and a little extra
+                // ReplayMap still paints outside its bounds - so we subtract padding and a little extra
                 val size = (columnWidth - 40f).coerceAtMost(500f)
                 val miniMap = LoadMapPreview(map, size, size)
                 if (!isActive) return@run
