@@ -4,21 +4,26 @@ import com.badlogic.gdx.graphics.Color
 import com.badlogic.gdx.scenes.scene2d.ui.Image
 import com.unciv.ui.images.ImageGetter
 
-enum class RankingType(val getImage: () -> Image?, val idForSerialization: String) {
+enum class RankingType(
+    label: String?,
+    val getImage: () -> Image?,
+    val idForSerialization: String
+) {
     // production, gold, happiness, and culture already have icons added when the line is `tr()`anslated
-    Score(
-        { ImageGetter.getImage("CityStateIcons/Cultured").apply { color = Color.FIREBRICK } },
-        "S"
-    ),
+    Score({ ImageGetter.getImage("CityStateIcons/Cultured").apply { color = Color.FIREBRICK } }, "S"),
     Population({ ImageGetter.getStatIcon("Population") }, "N"),
-    Crop_Yield({ ImageGetter.getStatIcon("Food") }, "C"),
-    Production({ null }, "P"),
-    Gold({ null }, "G"),
+    CropYield("Crop Yield", { ImageGetter.getStatIcon("Food") }, "C"),
+    Production("P"),
+    Gold("G"),
     Territory({ ImageGetter.getImage("OtherIcons/Hexagon") }, "T"),
     Force({ ImageGetter.getImage("OtherIcons/Shield") }, "F"),
-    Happiness({ null }, "H"),
+    Happiness("H"),
     Technologies({ ImageGetter.getStatIcon("Science") }, "W"),
-    Culture({ null }, "A");
+    Culture("A")
+    ;
+    val label = label ?: name
+    constructor(getImage: () -> Image?, idForSerialization: String) : this(null, getImage, idForSerialization)
+    constructor(idForSerialization: String) : this(null, { null }, idForSerialization)
 
     companion object {
         fun fromIdForSerialization(s: String): RankingType? =
