@@ -9,9 +9,9 @@ import com.unciv.logic.city.managers.CityFounder
 import com.unciv.logic.civilization.Civilization
 import com.unciv.logic.civilization.PlayerType
 import com.unciv.logic.map.MapSizeNew
+import com.unciv.logic.map.TileMap
 import com.unciv.logic.map.mapunit.MapUnit
 import com.unciv.logic.map.tile.Tile
-import com.unciv.logic.map.TileMap
 import com.unciv.models.Religion
 import com.unciv.models.metadata.BaseRuleset
 import com.unciv.models.metadata.GameSettings
@@ -28,6 +28,7 @@ import com.unciv.models.ruleset.nation.Nation
 import com.unciv.models.ruleset.tile.TileImprovement
 import com.unciv.models.ruleset.unique.UniqueType
 import com.unciv.models.ruleset.unit.BaseUnit
+import com.unciv.models.ruleset.unit.Promotion
 import com.unciv.models.ruleset.unit.UnitType
 
 class TestGame {
@@ -59,6 +60,9 @@ class TestGame {
         tileMap.mapParameters.mapSize = MapSizeNew(0, 0)
         tileMap.ruleset = ruleset
         tileMap.gameInfo = gameInfo
+
+        for (baseUnit in ruleset.units.values)
+            baseUnit.ruleset = ruleset
     }
 
     /** Makes a new rectangular tileMap and sets it in gameInfo. Removes all existing tiles. All new tiles have terrain [baseTerrain] */
@@ -135,28 +139,29 @@ class TestGame {
         replacePalace: Boolean = false,
         initialPopulation: Int = 0
     ): City {
-        val cityInfo = CityFounder().foundCity(civInfo, tile.position)
+        val city = CityFounder().foundCity(civInfo, tile.position)
         if (initialPopulation != 1)
-            cityInfo.population.addPopulation(initialPopulation - 1) // With defaults this will remove population
+            city.population.addPopulation(initialPopulation - 1) // With defaults this will remove population
 
         if (replacePalace && civInfo.cities.size == 1) {
             // Add a capital indicator without any other stats
             val palaceWithoutStats = createBuilding(UniqueType.IndicatesCapital.text)
-            cityInfo.cityConstructions.removeBuilding("Palace")
-            cityInfo.cityConstructions.addBuilding(palaceWithoutStats.name)
+            city.cityConstructions.removeBuilding("Palace")
+            city.cityConstructions.addBuilding(palaceWithoutStats.name)
         }
-        return cityInfo
+        return city
     }
 
     fun addTileToCity(city: City, tile: Tile) {
         city.tiles.add(tile.position)
     }
 
-    fun addUnit(name: String, civInfo: Civilization, tile: Tile): MapUnit {
+    fun addUnit(name: String, civInfo: Civilization, tile: Tile?): MapUnit {
         val baseUnit = ruleset.units[name]!!
         baseUnit.ruleset = ruleset
         val mapUnit = baseUnit.getMapUnit(civInfo)
-        mapUnit.putInTile(tile)
+        civInfo.units.addUnit(mapUnit)
+        if (tile!=null) mapUnit.putInTile(tile)
         return mapUnit
     }
 
@@ -203,4 +208,6 @@ class TestGame {
         createRulesetObject(ruleset.tileImprovements, *uniques) { TileImprovement() }
     fun createUnitType(vararg uniques: String) =
         createRulesetObject(ruleset.unitTypes, *uniques) { UnitType() }
+    fun createUnitPromotion(vararg uniques: String) =
+        createRulesetObject(ruleset.unitPromotions, *uniques) { Promotion() }
 }
